"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.clunk = exports.parser = void 0;
const generateHelp_1 = require("./lib/generateHelp");
const generateVersion_1 = require("./lib/generateVersion");
const parseValue_1 = require("./lib/parseValue");
function getConfigFlagByAlias(config, alias) {
    let matchingFlag = null;
    Object.entries(config).find(([flag, configItem]) => {
        const isMatch = configItem.alias === alias;
        if (isMatch)
            matchingFlag = flag;
        return isMatch;
    });
    return matchingFlag;
}
function toBoolean(text) {
    return text === 'true'
        ? true
        : text === 'false'
            ? false
            : null;
}
function parser([item, ...rest], config, inputs = [], flags = {}) {
    if (!item)
        return { inputs, flags };
    const [char1, char2] = Array.from(item);
    const isLongFlag = char2 === '-';
    const isShortFlag = !isLongFlag && char1 === '-';
    const flag = item.replace(/-/g, '');
    const isNextItemFlag = Array.from(rest[0] || '')[0] === '-';
    if (isLongFlag) {
        const flagType = config[flag]?.type;
        if (rest[0]) {
            const nextBoolean = toBoolean(rest[0]);
            if (isNextItemFlag) {
                const [f, v] = flag.split('=');
                flags[f] = (0, parseValue_1.parseValue)(v) || true;
            }
            else {
                if (flagType === Boolean) {
                    flags[flag] =
                        nextBoolean !== null
                            ? nextBoolean
                            : true;
                    if (nextBoolean !== null && rest[0])
                        rest.shift();
                }
                else if (flagType === String) {
                    flags[flag] = String(rest[0]);
                    rest.shift();
                }
                else if (flagType === Number) {
                    flags[flag] = Number(rest[0]);
                    rest.shift();
                }
                else if (nextBoolean !== null) {
                    flags[flag] = nextBoolean;
                    rest.shift();
                }
                else if (flag.length > 1) {
                    flags[flag] = rest[0];
                    rest.shift();
                }
                else if (flag.length === 1 &&
                    rest[0] &&
                    rest[1]) {
                    flags[flag] = rest[0];
                    rest.shift();
                }
                else {
                    flags[flag] = true;
                }
            }
        }
        else {
            const [f, v] = flag.split('=');
            flags[f] = (0, parseValue_1.parseValue)(v) || true;
        }
    }
    else if (isShortFlag) {
        const aliases = Array.from(item.replace(/-/g, '')).map((alias) => `--${getConfigFlagByAlias(config, alias) ||
            alias}`);
        // Send them back through
        rest = [...aliases, ...rest];
    }
    else {
        inputs.push(item);
    }
    const result = rest.length > 0
        ? parser(rest, config, inputs, flags)
        : { inputs, flags };
    return result;
}
exports.parser = parser;
function clunk(config, options) {
    const [, , ...rest] = process.argv;
    const { flags, inputs } = parser(rest, config || {});
    if (flags.help || flags.h) {
        console.log((0, generateHelp_1.generateHelp)(config, options));
        process.exit();
    }
    if (flags.version && options?.version) {
        console.log((0, generateVersion_1.generateVersion)(options));
        process.exit();
    }
    return { flags: flags, inputs };
}
exports.clunk = clunk;
//# sourceMappingURL=index.js.map