"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateHelp = exports.helpTemplate = void 0;
const generateVersion_1 = require("./generateVersion");
const helpTemplate = (optionsString, options) => `
${options ? (0, generateVersion_1.generateVersion)(options) : ''}

Usage:

Options
  ${optionsString}
`;
exports.helpTemplate = helpTemplate;
const len = (text) => Array.from(text).length;
function generateHelp(config, options) {
    const entries = Object.entries(config || {});
    const longestFlag = entries.reduce((prev, [flag]) => {
        const length = len(flag);
        return length > prev ? length : prev;
    }, 0);
    const optionsString = entries
        .map(([flag, { alias, type, description }]) => [
        alias ? `-${alias}` : '    ',
        `--${flag}`,
        // Spacer
        new Array(longestFlag - len(flag) + 2)
            .fill(' ')
            .join(''),
        description,
        `${typeof type()}`,
    ]
        .filter((item) => item)
        .join('  '))
        .join('\n');
    return (0, exports.helpTemplate)(optionsString, options);
}
exports.generateHelp = generateHelp;
//# sourceMappingURL=generateHelp.js.map